grab.util.timeout — Grab 0.6.41 documentation

# `grab.util.timeout`

## Module Contents

### Classes

`UndefinedParam` | Generic enumeration.
`Timeout` |

### Attributes

`UNDEFINED_PARAM` |
`DEFAULT_TOTAL_TIMEOUT` |

class grab.util.timeout.UndefinedParam

  Bases: `enum.Enum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  value

grab.util.timeout.UNDEFINED_PARAM :UndefinedParam

grab.util.timeout.DEFAULT_TOTAL_TIMEOUT

class grab.util.timeout.Timeout(total: None | float | UndefinedParam = UNDEFINED_PARAM, connect: None | float | UndefinedParam = UNDEFINED_PARAM, read: None | float | UndefinedParam = UNDEFINED_PARAM)
  __slots__ = ['total', 'connect', 'read']
  __repr__() → str

    Return repr(self).